/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.webfonts.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Webfont.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Fonts Developer API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Webfont extends GenericJson {

  /**
   * The name of the font.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String family;

  /**
   * The font files (with all supported scripts) for each one of the available variants, as a key :
   * value map.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.Map<String, String> files;

  /**
   * This kind represents a webfont object in the webfonts service.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The date (format "yyyy-MM-dd") the font was modified for the last time.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime lastModified;

  /**
   * The scripts supported by the font.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> subsets;

  /**
   * The available variants for the font.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> variants;

  /**
   * The font version.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String version;

  /**
   * The name of the font.
   * The value returned may be {@code null}.
   */
  public String getFamily() {
    return family;
  }

  /**
   * The name of the font.
   * The value set may be {@code null}.
   */
  public Webfont setFamily(String family) {
    this.family = family;
    return this;
  }

  /**
   * The font files (with all supported scripts) for each one of the available variants, as a key :
   * value map.
   * The value returned may be {@code null}.
   */
  public java.util.Map<String, String> getFiles() {
    return files;
  }

  /**
   * The font files (with all supported scripts) for each one of the available variants, as a key :
   * value map.
   * The value set may be {@code null}.
   */
  public Webfont setFiles(java.util.Map<String, String> files) {
    this.files = files;
    return this;
  }

  /**
   * This kind represents a webfont object in the webfonts service.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * This kind represents a webfont object in the webfonts service.
   * The value set may be {@code null}.
   */
  public Webfont setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The date (format "yyyy-MM-dd") the font was modified for the last time.
   * The value returned may be {@code null}.
   */
  public DateTime getLastModified() {
    return lastModified;
  }

  /**
   * The date (format "yyyy-MM-dd") the font was modified for the last time.
   * The value set may be {@code null}.
   */
  public Webfont setLastModified(DateTime lastModified) {
    this.lastModified = lastModified;
    return this;
  }

  /**
   * The scripts supported by the font.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getSubsets() {
    return subsets;
  }

  /**
   * The scripts supported by the font.
   * The value set may be {@code null}.
   */
  public Webfont setSubsets(java.util.List<String> subsets) {
    this.subsets = subsets;
    return this;
  }

  /**
   * The available variants for the font.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getVariants() {
    return variants;
  }

  /**
   * The available variants for the font.
   * The value set may be {@code null}.
   */
  public Webfont setVariants(java.util.List<String> variants) {
    this.variants = variants;
    return this;
  }

  /**
   * The font version.
   * The value returned may be {@code null}.
   */
  public String getVersion() {
    return version;
  }

  /**
   * The font version.
   * The value set may be {@code null}.
   */
  public Webfont setVersion(String version) {
    this.version = version;
    return this;
  }

}
